@@ -1,7 +1,6 @@
 import pygame
 import os
-from time import time
-import numpy as np
+import time
 from typing import Optional, Dict
 import json
 from _thread import start_new_thread
@@ -25,7 +24,7 @@ from .skip_cinematic_listener import SkipCinematicListener
 
 
 class Game:
-    def __init__(self, config: GameConfig, win_data: dict):
+    def __init__(self, config: GameConfig, win_data: dict, ready_state: dict):
         self.config = config
         self.resources_manager = ResourcesManager(self.config.resources_dir)
         self.resources_manager.load_resources()
@@ -214,13 +213,13 @@ class Game:
                 "cond": lambda: self.menu_state == "config" and self.menu.browse_files,
             },
             {
-                "text": t("Browse directory") + ": →" + " | " + t("Parent directory") + ": ←",
+                "text": t("Browse directory") + ": ->" + " | " + t("Parent directory") + ": <-",
                 "read_only": True,
                 "small": True,
                 "cond": lambda: self.menu_state == "config" and self.menu.browse_files,
             },
             {
-                "text":  t("Select directory") + t(": ↩") + " | " + t("Cancel") + ": " + t("Escape key"),
+                "text":  t("Select directory") + ": " + t("Enter") + " | " + t("Cancel") + ": " + t("Escape"),
                 "read_only": True,
                 "small": True,
                 "cond": lambda: self.menu_state == "config" and self.menu.browse_files,
@@ -252,6 +251,8 @@ class Game:
                      else (win_data["screen_w"] - 2*win_data["margin"],
                            win_data["screen_h"] - 2*win_data["margin"]))
 
+        ready_state["ready"] = True
+
         self.render = Render(pygame.display.set_mode(surf_size, win_flag))
 
         if self.scene.is_none():
