@@ -1,4 +1,5 @@
 import pygame
+import os
 from functools import reduce
 from typing import Optional, List, Set, Tuple
 from .. import Sprite
@@ -47,19 +48,18 @@ class Render:
             "get_bounds": lambda: self.drawing_surface.get_rect()
         })
 
-        self.font_cta = pygame.font.SysFont("sans", 28)
-        self.font_cta.set_bold(True)
-        self.font_dialog = pygame.font.SysFont("sans", 20)
-        self.font_small = pygame.font.SysFont("sans", 12)
+        font_path = os.getenv("FONT_PATH")
 
-        self.font_menu = pygame.font.SysFont("sans", 50)
-        self.font_menu_secondary = pygame.font.SysFont("sans", 35)
-        self.font_menu_read_only = pygame.font.SysFont("sans", 25)
-        self.font_menu_read_only.set_italic(True)
-        self.font_menu_small = pygame.font.SysFont("sans", 20)
-        self.font_menu_file_explorer_dirname = pygame.font.SysFont("sans", 20)
-        self.font_menu_file_explorer_dirname.set_bold(True)
-        self.font_menu_notification = pygame.font.SysFont("sans", 25)
+        self.font_cta = pygame.font.Font(font_path, 35)
+        self.font_dialog = pygame.font.Font(font_path, 25)
+        self.font_small = pygame.font.Font(font_path, 16)
+
+        self.font_menu = pygame.font.Font(font_path, 40)
+        self.font_menu_secondary = pygame.font.Font(font_path, 30)
+        self.font_menu_read_only = pygame.font.Font(font_path, 25)
+        self.font_menu_small = pygame.font.Font(font_path, 20)
+        self.font_menu_file_explorer_dirname = pygame.font.Font(font_path, 20)
+        self.font_menu_notification = pygame.font.Font(font_path, 25)
 
         self.prev_left = 0
 
@@ -132,7 +132,7 @@ class Render:
         self.__render()
 
     def draw_fade_out(self, duration):
-        alpha = int(255 / duration)
+        alpha = int(255 / max(1, duration))
         size = self.drawing_surface.get_size()
         surf = pygame.Surface(size, pygame.SRCALPHA)
         surf.fill((0, 0, 0, alpha))
@@ -201,7 +201,7 @@ class Render:
             h = get_item_h(item)
 
             item_color = white if item.selected else grey
-            item_surf = font.render(item.text, True, item_color)
+            item_surf = font.render(item.text, False, item_color)
 
             self.menu_drawing_surface.blit(item_surf, item_pos)
 
@@ -254,11 +254,11 @@ class Render:
                 left_shift = 50 if f_it.abs_path else 25 if f_it.dirname else 10
                 if f_it.selected:
                     it_surf.fill(white)
-                    it_surf.blit(font.render(f_it.text, True, (0, 0, 0)),
+                    it_surf.blit(font.render(f_it.text, False, (0, 0, 0)),
                                  (left_shift, 0))
                 else:
                     color = white if f_it.abs_path else grey if f_it.dirname else grey2
-                    it_surf.blit(font.render(f_it.text, True, color),
+                    it_surf.blit(font.render(f_it.text, False, color),
                                  (left_shift, 0))
 
                 f_explorer_surf.blit(it_surf, item_pos - explorer_pos)
@@ -271,7 +271,7 @@ class Render:
             line_h = self.font_menu_notification.get_height()
             for (i, l) in enumerate(lines):
                 self.menu_drawing_surface.blit(
-                    self.font_menu_notification.render(l, True, yellow),
+                    self.font_menu_notification.render(l, False, yellow),
                     (10, 10 + i*line_h))
 
         self.__render(True)
@@ -313,10 +313,10 @@ class Render:
         cta_surf.fill((0, 0, 0, 127))
 
         cta_surf.blit(self.font_cta.render(
-            cta, True, (255, 255, 255)), (x_pos_cta, y_pos_cta))
+            cta, False, (255, 255, 255)), (x_pos_cta, y_pos_cta))
 
         cta_surf.blit(self.font_small.render(
-            hint, True, (255, 255, 255)), (x_pos_hint, y_pos_cta + line_height))
+            hint, False, (255, 255, 255)), (x_pos_hint, y_pos_cta + line_height))
 
         unscaled_render_size = self.render_size / self.scale_factor
         unscaled_screen_size = self.screen_size / self.scale_factor
@@ -416,7 +416,7 @@ class Render:
         surf.blit(render_img, img_pos)
 
         text_surf = self.font_cta.render(
-            feedback.message, True, (200, 200, 200))
+            feedback.message, False, (200, 200, 200))
 
         surf.blit(text_surf, ((unscaled_screen_size[0] - text_surf.get_size()[0]) / 2,
                               img_pos[1] + render_size[1] + 20))
