@@ -1,7 +1,6 @@
 from .game import Game, GameConfig
 from .generic import LoadingWindow
 from _thread import start_new_thread
-from typing import Callable
 import sys
 import os
 import pygame
@@ -13,13 +12,13 @@ def show_loading(state, loading_window):
 
 
 def run_game(argv):
-    # if getattr(sys, 'frozen', False) and hasattr(sys, '_MEIPASS'):
-    #     os.chdir(sys._MEIPASS)
+    os.environ["SDL_VIDEO_WINDOW_POS"] = "50,50"
 
-    os.environ['SDL_VIDEO_WINDOW_POS'] = '60,30'  # y x
-    os.environ['SDL_VIDEO_CENTERED'] = '0'
+    os.environ["FONT_PATH"] = os.path.join(
+        os.path.dirname(__file__), "PerfectDosVGAWin.ttf")
 
     pygame.init()
+
     screen_info = pygame.display.Info()
 
     win_data = {
@@ -51,9 +50,7 @@ def run_game(argv):
 
     start_new_thread(show_loading, (ready_state, loading_win))
 
-    game = Game(conf, win_data)
-
-    ready_state["ready"] = True
+    game = Game(conf, win_data, ready_state)
 
     game.main_loop()
 
